@@ -19,7 +19,6 @@ from oslo_config import cfg
 from oslo_log import log as logging
 
 from designate.context import DesignateContext
-from designate.mdns import rpcapi as mdns_api
 from designate.plugin import DriverPlugin
 
 LOG = logging.getLogger(__name__)
@@ -52,16 +51,6 @@ class Backend(DriverPlugin):
         self.max_retries = CONF['service:worker'].poll_max_retries
         self.delay = CONF['service:worker'].poll_delay
 
-    def start(self):
-        LOG.info('Starting %s backend', self.get_canonical_name())
-
-    def stop(self):
-        LOG.info('Stopped %s backend', self.get_canonical_name())
-
-    @property
-    def mdns_api(self):
-        return mdns_api.MdnsAPI.get_instance()
-
     # Core Backend Interface
     @abc.abstractmethod
     def create_zone(self, context, zone):
@@ -81,12 +70,8 @@ class Backend(DriverPlugin):
         """
         LOG.debug('Update Zone')
 
-        self.mdns_api.notify_zone_changed(
-            context, zone, self.host, self.port, self.timeout,
-            self.retry_interval, self.max_retries, self.delay)
-
     @abc.abstractmethod
-    def delete_zone(self, context, zone):
+    def delete_zone(self, context, zone, zone_params):
         """
         Delete a DNS zone.
 
