@@ -90,9 +90,9 @@ class InfobloxObjectManipulator(object):
                 net_view_name=net_view,
                 dns_view_name=dns_view)
         except exc.InfobloxException as e:
-            LOG.warning(_("Issue happens during views creating: %s"), e)
+            LOG.warning("Issue happens during views creating: %s", e)
 
-        LOG.debug("net_view: %s, dns_view: %s" % (net_view, dns_view))
+        LOG.debug("net_view: %s, dns_view: %s", net_view, dns_view)
         return dns_view
 
     def get_dns_view(self, tenant):
@@ -122,14 +122,16 @@ class InfobloxObjectManipulator(object):
                 'zone_auth',
                 {'fqdn': fqdn, 'view': dns_view},
                 {'ns_group': self.connector.ns_group,
-                 'restart_if_needed': True, 'zone_format': zone_format},
+                 'zone_format': zone_format},
                 check_if_exists=True)
+            self._restart_if_needed()
         except exc.InfobloxCannotCreateObject as e:
             LOG.warning(e)
 
     def delete_zone_auth(self, fqdn):
         self._delete_infoblox_object(
             'zone_auth', {'fqdn': fqdn})
+        self._restart_if_needed()
 
     def _create_infoblox_object(self, obj_type, payload,
                                 additional_create_kwargs=None,
@@ -142,15 +144,15 @@ class InfobloxObjectManipulator(object):
         if check_if_exists:
             ib_object = self._get_infoblox_object_or_none(obj_type, payload)
             if ib_object:
-                LOG.info(_(
-                    "Infoblox %(obj_type)s already exists: %(ib_object)s"),
+                LOG.info(
+                    "Infoblox %(obj_type)s already exists: %(ib_object)s",
                     {'obj_type': obj_type, 'ib_object': ib_object})
 
         if not ib_object:
             payload.update(additional_create_kwargs)
             ib_object = self.connector.create_object(obj_type, payload,
                                                      return_fields)
-            LOG.info(_("Infoblox %(obj_type)s was created: %(ib_object)s"),
+            LOG.info("Infoblox %(obj_type)s was created: %(ib_object)s",
                      {'obj_type': obj_type, 'ib_object': ib_object})
 
         return ib_object
@@ -186,7 +188,7 @@ class InfobloxObjectManipulator(object):
 
     def _update_infoblox_object_by_ref(self, ref, update_kwargs):
         self.connector.update_object(ref, update_kwargs)
-        LOG.info(_('Infoblox object was updated: %s'), ref)
+        LOG.info('Infoblox object was updated: %s', ref)
 
     def _delete_infoblox_object(self, obj_type, payload):
         ib_object_ref = None
@@ -204,4 +206,26 @@ class InfobloxObjectManipulator(object):
 
         if ib_object_ref:
             self.connector.delete_object(ib_object_ref)
-            LOG.info(_('Infoblox object was deleted: %s'), ib_object_ref)
+            LOG.info('Infoblox object was deleted: %s', ib_object_ref)
+
+    def _restart_if_needed(self):
+        ib_object_ref = None
+        obj_type = 'grid'
+        warn_msg = ('Infoblox %(obj_type)s will not be restarted because'
+                    ' the API object reference cannot be found')
+        try:
+            ib_object_ref = self._get_infoblox_object_or_none(obj_type)
+            if not ib_object_ref:
+                LOG.warning(warn_msg, {'obj_type': obj_type})
+        except exc.InfobloxSearchError as e:
+            LOG.warning(warn_msg, {'obj_type': obj_type})
+            LOG.info(e)
+
+        if ib_object_ref:
+            payload = {
+                "restart_option": "RESTART_IF_NEEDED",
+                "mode": "GROUPED",
+                "services": ["DNS"],
+            }
+            self.connector.call_func(
+                'restartservices', ib_object_ref, payload)
