@@ -19,7 +19,7 @@ from oslo_log import log as logging
 from oslo_reports import guru_meditation_report as gmr
 
 import designate.conf
-from designate import hookpoints
+from designate import heartbeat_emitter
 from designate import service
 from designate import utils
 from designate import version
@@ -35,10 +35,8 @@ def main():
     logging.setup(CONF, 'designate')
     gmr.TextGuruMeditation.setup_autorun(version)
 
-    hookpoints.log_hook_setup()
-
     server = worker_service.Service()
-    heartbeat = service.Heartbeat(server.service_name)
+    heartbeat = heartbeat_emitter.get_heartbeat_emitter(server.service_name)
     service.serve(server, workers=CONF['service:worker'].workers)
     heartbeat.start()
     service.wait()
