@@ -23,9 +23,15 @@ KNOT2_GROUP = cfg.OptGroup(
 KNOT2_OPTS = [
     cfg.StrOpt('knotc_cmd_name',
                help='knotc executable path or rootwrap command name',
-               default='knotc'),
+               default='knotc',
+               deprecated_for_removal=True,
+               deprecated_since='Antelope(2023.1)',
+               deprecated_reason='The agent framework is deprecated.'),
     cfg.StrOpt('query_destination', default='127.0.0.1',
-               help='Host to query when finding zones'),
+               help='Host to query when finding zones',
+               deprecated_for_removal=True,
+               deprecated_since='Antelope(2023.1)',
+               deprecated_reason='The agent framework is deprecated.'),
 ]
 
 
