@@ -14,7 +14,6 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 import copy
-import itertools
 
 from keystoneauth1.access import service_catalog as ksa_service_catalog
 from keystoneauth1 import plugin
@@ -33,16 +32,20 @@ class DesignateContext(context.RequestContext):
     _abandon = None
     original_project_id = None
     _edit_managed_records = False
+    _hard_delete = False
     _client_addr = None
+    _delete_shares = False
     FROM_DICT_EXTRA_KEYS = [
         'original_project_id', 'service_catalog', 'all_tenants', 'abandon',
         'edit_managed_records', 'tsigkey_id', 'hide_counts', 'client_addr',
+        'hard_delete', 'delete_shares'
     ]
 
     def __init__(self, service_catalog=None, all_tenants=False, abandon=None,
                  tsigkey_id=None, original_project_id=None,
                  edit_managed_records=False, hide_counts=False,
-                 client_addr=None, user_auth_plugin=None, **kwargs):
+                 client_addr=None, user_auth_plugin=None,
+                 hard_delete=False, delete_shares=False, **kwargs):
         super(DesignateContext, self).__init__(**kwargs)
 
         self.user_auth_plugin = user_auth_plugin
@@ -54,8 +57,10 @@ class DesignateContext(context.RequestContext):
         self.all_tenants = all_tenants
         self.abandon = abandon
         self.edit_managed_records = edit_managed_records
+        self.hard_delete = hard_delete
         self.hide_counts = hide_counts
         self.client_addr = client_addr
+        self.delete_shares = delete_shares
 
     def deepcopy(self):
         d = self.to_dict()
@@ -96,15 +101,17 @@ class DesignateContext(context.RequestContext):
             'all_tenants': self.all_tenants,
             'abandon': self.abandon,
             'edit_managed_records': self.edit_managed_records,
+            'hard_delete': self.hard_delete,
             'tsigkey_id': self.tsigkey_id,
             'hide_counts': self.hide_counts,
             'client_addr': self.client_addr,
+            'delete_shares': self.delete_shares,
         })
 
         return copy.deepcopy(d)
 
     def elevated(self, show_deleted=None, all_tenants=False,
-                 edit_managed_records=False):
+                 edit_managed_records=False, hard_delete=False):
         """Return a version of this context with admin flag set.
         Optionally set all_tenants and edit_managed_records
         """
@@ -125,6 +132,9 @@ class DesignateContext(context.RequestContext):
         if edit_managed_records:
             context.edit_managed_records = True
 
+        if hard_delete:
+            context.hard_delete = True
+
         return context
 
     def sudo(self, project_id):
@@ -145,21 +155,6 @@ class DesignateContext(context.RequestContext):
 
         return cls(None, **kwargs)
 
-    @classmethod
-    def get_context_from_function_and_args(cls, function, args, kwargs):
-        """
-        Find an arg of type DesignateContext and return it.
-
-        This is useful in a couple of decorators where we don't
-        know much about the function we're wrapping.
-        """
-
-        for arg in itertools.chain(kwargs.values(), args):
-            if isinstance(arg, cls):
-                return arg
-
-        return None
-
     @property
     def all_tenants(self):
         return self._all_tenants
@@ -198,6 +193,16 @@ class DesignateContext(context.RequestContext):
             policy.check('edit_managed_records', self)
         self._edit_managed_records = value
 
+    @property
+    def hard_delete(self):
+        return self._hard_delete
+
+    @hard_delete.setter
+    def hard_delete(self, value):
+        if value:
+            policy.check('hard_delete', self)
+        self._hard_delete = value
+
     @property
     def client_addr(self):
         return self._client_addr
@@ -206,6 +211,14 @@ class DesignateContext(context.RequestContext):
     def client_addr(self, value):
         self._client_addr = value
 
+    @property
+    def delete_shares(self):
+        return self._delete_shares
+
+    @delete_shares.setter
+    def delete_shares(self, value):
+        self._delete_shares = value
+
     def get_auth_plugin(self):
         if self.user_auth_plugin:
             return self.user_auth_plugin
