@@ -179,9 +179,7 @@ class ApiV2TldsTest(ApiV2TestCase):
 
         correct_results = [1, 2]
 
-        for get_url, correct_result in \
-                zip(get_urls, correct_results):
-
+        for get_url, correct_result in zip(get_urls, correct_results):
             self.policy({'find_tlds': '@'})
             response = self.client.get(get_url)
 
