@@ -30,33 +30,57 @@ class SqlalchemyStorageTest(StorageTestCase, TestCase):
 
     def test_schema_table_names(self):
         table_names = [
-            u'blacklists',
-            u'migrate_version',
-            u'pool_also_notifies',
-            u'pool_attributes',
-            u'pool_nameservers',
-            u'pool_ns_records',
-            u'pool_target_masters',
-            u'pool_target_options',
-            u'pool_targets',
-            u'pools',
-            u'quotas',
-            u'records',
-            u'recordsets',
-            u'service_statuses',
-            u'tlds',
-            u'tsigkeys',
-            u'zone_attributes',
-            u'zone_masters',
-            u'zone_tasks',
-            u'zone_transfer_accepts',
-            u'zone_transfer_requests',
-            u'zones'
+            'blacklists',
+            'pool_also_notifies',
+            'pool_attributes',
+            'pool_nameservers',
+            'pool_ns_records',
+            'pool_target_masters',
+            'pool_target_options',
+            'pool_targets',
+            'pools',
+            'quotas',
+            'records',
+            'recordsets',
+            'service_statuses',
+            'shared_zones',
+            'tlds',
+            'tsigkeys',
+            'zone_attributes',
+            'zone_masters',
+            'zone_tasks',
+            'zone_transfer_accepts',
+            'zone_transfer_requests',
+            'zones'
         ]
-        self.assertEqual(table_names, self.storage.engine.table_names())
+        inspector = self.storage.get_inspector()
+
+        actual_table_names = inspector.get_table_names()
+
+        # We have transitioned database schema migration tools.
+        # They use different tracking tables. Accomidate that one or both
+        # may exist in this test.
+        migration_table_found = False
+        if ('migrate_version' in actual_table_names or
+                'alembic_version' in actual_table_names):
+            migration_table_found = True
+        self.assertTrue(
+            migration_table_found, 'A DB migration table was not found.'
+        )
+        try:
+            actual_table_names.remove('migrate_version')
+        except ValueError:
+            pass
+        try:
+            actual_table_names.remove('alembic_version')
+        except ValueError:
+            pass
+
+        self.assertEqual(table_names, actual_table_names)
 
     def test_schema_table_indexes(self):
-        indexes_t = self.storage.engine.execute("SELECT * FROM sqlite_master WHERE type = 'index';")  # noqa
+        indexes_t = self.storage.engine.execute(
+            "SELECT * FROM sqlite_master WHERE type = 'index';")
 
         indexes = {}  # table name -> index names -> cmd
         for _, index_name, table_name, num, cmd in indexes_t:
