@@ -17,24 +17,30 @@
 import json
 from unittest import mock
 
+import oslotest.base
 import requests
 
 from designate.backend import impl_akamai_v2 as akamai
+from designate import context
 from designate import exceptions
 from designate import objects
-import designate.tests
 from designate.tests import fixtures
 
 
-class AkamaiBackendTestCase(designate.tests.TestCase):
+class AkamaiBackendTestCase(oslotest.base.BaseTestCase):
     def setUp(self):
         super(AkamaiBackendTestCase, self).setUp()
+
+        self.admin_context = mock.Mock()
+        mock.patch.object(
+            context.DesignateContext, 'get_admin_context',
+            return_value=self.admin_context).start()
+
         self.zone = objects.Zone(
             id='cca7908b-dad4-4c50-adba-fb67d4c556e8',
             name='example.com.',
             email='example@example.com'
         )
-
         self.target = {
             'id': '4588652b-50e7-46b9-b688-a9bad40a873e',
             'type': 'akamai_v2',
@@ -103,7 +109,7 @@ class AkamaiBackendTestCase(designate.tests.TestCase):
             json={
                 'comment': 'Created by Designate for Tenant %s' % project_id,
                 'masters': ['192.168.1.1', '192.168.1.2'],
-                'type': 'secondary', 'zone': u'example.com.'
+                'type': 'secondary', 'zone': 'example.com.'
             },
             params={
                 'gid': '777',
@@ -134,7 +140,7 @@ class AkamaiBackendTestCase(designate.tests.TestCase):
             json={
                 'comment': 'Created by Designate for Tenant %s' % project_id,
                 'masters': ['192.168.1.1', '192.168.1.2'],
-                'type': 'secondary', 'zone': u'example.com.'
+                'type': 'secondary', 'zone': 'example.com.'
             },
             params={
                 'gid': '777',
@@ -340,8 +346,8 @@ class AkamaiBackendTestCase(designate.tests.TestCase):
             self.gen_response(200, 'Success', {'isComplete': True})
         ]
 
-        with fixtures.random_seed(0), \
-                mock.patch.object(akamai.time, 'sleep') as mock_sleep:
+        with fixtures.random_seed(0), mock.patch.object(akamai.time,
+                                                        'sleep') as mock_sleep:
             mock_sleep.return_value = None
             backend.delete_zone(self.admin_context, self.zone)
 
@@ -390,8 +396,8 @@ class AkamaiBackendTestCase(designate.tests.TestCase):
             self.gen_response(200, 'Success', {'isComplete': False})
         ]
 
-        with fixtures.random_seed(0), \
-                mock.patch.object(akamai.time, 'sleep') as mock_sleep:
+        with fixtures.random_seed(0), mock.patch.object(akamai.time,
+                                                        'sleep') as mock_sleep:
             mock_sleep.return_value = None
             self.assertRaisesRegex(
                 exceptions.Backend,
@@ -444,12 +450,12 @@ class AkamaiBackendTestCase(designate.tests.TestCase):
 
         mock_post.assert_has_calls([
             mock.call(
-                json={'zones': [u'example.com.']},
+                json={'zones': ['example.com.']},
                 params={'force': True},
                 url='https://host_value/config-dns/v2/zones/delete-requests'
             ),
             mock.call(
-                json={'zones': [u'example.com.']},
+                json={'zones': ['example.com.']},
                 params={'force': False},
                 url='https://host_value/config-dns/v2/zones/delete-requests'
             )
@@ -483,12 +489,12 @@ class AkamaiBackendTestCase(designate.tests.TestCase):
 
         mock_post.assert_has_calls([
             mock.call(
-                json={'zones': [u'example.com.']},
+                json={'zones': ['example.com.']},
                 params={'force': True},
                 url='https://host_value/config-dns/v2/zones/delete-requests'
             ),
             mock.call(
-                json={'zones': [u'example.com.']},
+                json={'zones': ['example.com.']},
                 params={'force': False},
                 url='https://host_value/config-dns/v2/zones/delete-requests'
             )
