@@ -12,30 +12,35 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
+
 from unittest import mock
 
+import oslotest.base
 import requests_mock
 
 from designate.backend import impl_infoblox
 from designate.backend.impl_infoblox import ibexceptions
+from designate import context
 from designate import exceptions
-from designate.mdns import rpcapi as mdns_rpcapi
 from designate import objects
-import designate.tests
 
 
-class InfobloxBackendTestCase(designate.tests.TestCase):
+class InfobloxBackendTestCase(oslotest.base.BaseTestCase):
     def setUp(self):
         super(InfobloxBackendTestCase, self).setUp()
         self.base_address = 'https://localhost/wapi'
 
-        self.context = self.get_context()
+        self.context = mock.Mock()
+        self.admin_context = mock.Mock()
+        mock.patch.object(
+            context.DesignateContext, 'get_admin_context',
+            return_value=self.admin_context).start()
+
         self.zone = objects.Zone(
             id='e2bed4dc-9d01-11e4-89d3-123b93f75cba',
             name='example.com.',
             email='example@example.com',
         )
-
         self.target = {
             'id': '4588652b-50e7-46b9-b688-a9bad40a873e',
             'type': 'infoblox',
@@ -68,13 +73,9 @@ class InfobloxBackendTestCase(designate.tests.TestCase):
 
         self.backend.create_zone(self.context, self.zone)
 
-    @mock.patch.object(mdns_rpcapi.MdnsAPI, 'notify_zone_changed')
-    def test_update_zone(self, mock_notify_zone_changed):
+    def test_update_zone(self):
         self.backend.update_zone(self.context, self.zone)
 
-        mock_notify_zone_changed.assert_called_with(
-            self.context, self.zone, '127.0.0.1', 53, 30, 15, 10, 5)
-
     @requests_mock.mock()
     def test_delete_zone(self, req_mock):
         req_mock.post(
@@ -87,6 +88,11 @@ class InfobloxBackendTestCase(designate.tests.TestCase):
             json={},
         )
 
+        req_mock.get(
+            '%s/v2.0/grid' % self.base_address,
+            json={},
+        )
+
         self.backend.create_zone(self.context, self.zone)
         self.backend.delete_zone(self.context, self.zone)
 
