@@ -166,6 +166,7 @@ class TestZoneActionOnTarget(oslotest.base.BaseTestCase):
 
         self.context = mock.Mock()
         self.executor = mock.Mock()
+        self.zone_params = mock.Mock()
 
     @mock.patch.object(dnsutils, 'notify')
     def test_call_create(self, mock_notify):
@@ -175,6 +176,7 @@ class TestZoneActionOnTarget(oslotest.base.BaseTestCase):
             self.context,
             self.zone,
             self.target,
+            self.zone_params
         )
 
         self.assertTrue(self.actor())
@@ -193,6 +195,7 @@ class TestZoneActionOnTarget(oslotest.base.BaseTestCase):
             self.context,
             self.zone,
             self.target,
+            self.zone_params,
         )
 
         self.assertTrue(self.actor())
@@ -211,6 +214,7 @@ class TestZoneActionOnTarget(oslotest.base.BaseTestCase):
             self.context,
             self.zone,
             self.target,
+            self.zone_params
         )
 
         self.assertTrue(self.actor())
@@ -227,6 +231,7 @@ class TestZoneActionOnTarget(oslotest.base.BaseTestCase):
             self.context,
             self.zone,
             self.target,
+            self.zone_params
         )
 
         self.assertFalse(self.actor())
@@ -282,21 +287,6 @@ class TestSendNotify(oslotest.base.BaseTestCase):
             self.actor
         )
 
-    @mock.patch.object(dnsutils, 'notify')
-    def test_call_dont_notify(self, mock_notify):
-        CONF.set_override('notify', False, 'service:worker')
-
-        self.zone = objects.Zone(name='example.org.')
-        self.actor = zone.SendNotify(
-            self.executor,
-            self.zone,
-            self.target,
-        )
-
-        self.assertTrue(self.actor())
-
-        mock_notify.assert_not_called()
-
 
 class TestZoneActor(oslotest.base.BaseTestCase):
     def setUp(self):
@@ -304,11 +294,13 @@ class TestZoneActor(oslotest.base.BaseTestCase):
         self.context = mock.Mock()
         self.pool = mock.Mock()
         self.executor = mock.Mock()
+        self.zone_params = mock.Mock()
         self.actor = zone.ZoneActor(
             self.executor,
             self.context,
             self.pool,
             mock.Mock(action='CREATE'),
+            self.zone_params
         )
 
     def test_threshold_from_config(self):
@@ -318,7 +310,7 @@ class TestZoneActor(oslotest.base.BaseTestCase):
 
         self.assertEqual(
             cfg.CONF['service:worker'].threshold_percentage,
-            actor.threshold
+            actor.threshold_percentage
         )
 
     def test_execute(self):
@@ -375,7 +367,7 @@ class TestZonePoller(oslotest.base.BaseTestCase):
         self.context = mock.Mock()
         self.pool = mock.Mock()
         self.zone = mock.Mock(name='example.com.', serial=1)
-        self.threshold = 80
+        self.threshold_percentage = 80
         self.executor = mock.Mock()
         self.poller = zone.ZonePoller(
             self.executor,
@@ -383,11 +375,13 @@ class TestZonePoller(oslotest.base.BaseTestCase):
             self.pool,
             self.zone,
         )
-        self.poller._threshold = self.threshold
+        self.poller._threshold = self.threshold_percentage
 
     def test_constructor(self):
         self.assertTrue(self.poller)
-        self.assertEqual(self.threshold, self.poller.threshold)
+        self.assertEqual(
+            self.threshold_percentage, self.poller.threshold_percentage
+        )
 
     def test_call_on_success(self):
         ns_results = [2] * 8 + [0] * 2
@@ -529,7 +523,7 @@ class TestZonePollerPolling(oslotest.base.BaseTestCase):
         self.context = mock.Mock()
         self.zone = mock.Mock(name='example.com.', action='UPDATE', serial=10)
         self.pool = mock.Mock(nameservers=['ns1', 'ns2'])
-        self.threshold = 80
+        self.threshold_percentage = 80
 
         self.poller = zone.ZonePoller(
             self.executor,
@@ -593,6 +587,7 @@ class TestUpdateStatus(oslotest.base.BaseTestCase):
     def test_call_on_delete(self):
         self.task.zone.action = 'DELETE'
         self.task.zone.status = 'SUCCESS'
+        self.task.zone.serial = 0
 
         self.task()
 
@@ -603,6 +598,7 @@ class TestUpdateStatus(oslotest.base.BaseTestCase):
     def test_call_on_success(self):
         self.task.zone.action = 'UPDATE'
         self.task.zone.status = 'SUCCESS'
+        self.task.zone.serial = 0
 
         self.task()
 
@@ -611,6 +607,7 @@ class TestUpdateStatus(oslotest.base.BaseTestCase):
 
     def test_call_central_call(self):
         self.task.zone.status = 'SUCCESS'
+        self.task.zone.serial = 0
 
         self.task()
 
@@ -625,6 +622,7 @@ class TestUpdateStatus(oslotest.base.BaseTestCase):
     def test_call_on_delete_error(self):
         self.task.zone.action = 'DELETE'
         self.task.zone.status = 'ERROR'
+        self.task.zone.serial = 0
 
         self.task()
 
@@ -635,6 +633,7 @@ class TestUpdateStatus(oslotest.base.BaseTestCase):
     def test_call_on_create_error(self):
         self.task.zone.action = 'CREATE'
         self.task.zone.status = 'ERROR'
+        self.task.zone.serial = 0
 
         self.task()
 
@@ -645,6 +644,7 @@ class TestUpdateStatus(oslotest.base.BaseTestCase):
     def test_call_on_update_error(self):
         self.task.zone.action = 'UPDATE'
         self.task.zone.status = 'ERROR'
+        self.task.zone.serial = 0
 
         self.task()
 
