@@ -14,64 +14,56 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 from collections import namedtuple
+import errno
+import socket
 import time
 
 import dns
 from oslo_config import cfg
 from oslo_log import log as logging
+from oslo_utils import timeutils
 
 from designate import dnsutils
 from designate import exceptions
+from designate import objects
 from designate import utils
 from designate.worker.tasks import base
 
 LOG = logging.getLogger(__name__)
 CONF = cfg.CONF
 
-
-def percentage(part, whole):
-    if whole == 0:
-        return 0
-    return 100 * float(part) / float(whole)
-
-
-class ThresholdMixin(object):
-    @property
-    def threshold(self):
-        if not hasattr(self, '_threshold') or self._threshold is None:
-            self._threshold = CONF['service:worker'].threshold_percentage
-        return self._threshold
-
-    def _compare_threshold(self, successes, total):
-        p = percentage(successes, total)
-        return p >= self.threshold
-
-
 ######################
 # CRUD Zone Operations
 ######################
 
+
 class ZoneActionOnTarget(base.Task):
     """
     Perform a Create/Update/Delete of the zone on a pool target
 
     :return: Success/Failure of the target action (bool)
     """
-    def __init__(self, executor, context, zone, target):
+
+    def __init__(self, executor, context, zone, target, zone_params):
         super(ZoneActionOnTarget, self).__init__(executor)
         self.zone = zone
         self.action = zone.action
         self.target = target
         self.context = context
         self.task_name = 'ZoneActionOnTarget-%s' % self.action.title()
+        self.zone_params = zone_params
 
     def __call__(self):
-        LOG.debug("Attempting %(action)s zone %(zone)s on %(target)s",
-                  {
-                      'action': self.action,
-                      'zone': self.zone.name,
-                      'target': self.target
-                  })
+        LOG.debug(
+            'Attempting to %(action)s zone_name=%(zone_name)s '
+            'zone_id=%(zone_id)s on target=%(target)s',
+            {
+                'action': self.action,
+                'zone_name': self.zone.name,
+                'zone_id': self.zone.id,
+                'target': self.target,
+            }
+        )
 
         for retry in range(0, self.max_retries):
             try:
@@ -79,13 +71,23 @@ class ZoneActionOnTarget(base.Task):
                     self.target.backend.create_zone(self.context, self.zone)
                     SendNotify(self.executor, self.zone, self.target)()
                 elif self.action == 'DELETE':
-                    self.target.backend.delete_zone(self.context, self.zone)
+                    self.target.backend.delete_zone(self.context, self.zone,
+                                                    self.zone_params)
                 else:
                     self.target.backend.update_zone(self.context, self.zone)
                     SendNotify(self.executor, self.zone, self.target)()
 
-                LOG.debug("Successful %s zone %s on %s",
-                          self.action, self.zone.name, self.target)
+                LOG.debug(
+                    'Successfully performed %(action)s for '
+                    'zone_name=%(zone_name)s zone_id=%(zone_id)s '
+                    'on target=%(target)s',
+                    {
+                        'action': self.action,
+                        'zone_name': self.zone.name,
+                        'zone_id': self.zone.id,
+                        'target': self.target,
+                    }
+                )
                 return True
             except Exception as e:
                 LOG.info(
@@ -114,41 +116,77 @@ class SendNotify(base.Task):
     :raises: Various exceptions from dnspython
     :return: Success/Failure delivering the notify (bool)
     """
+
     def __init__(self, executor, zone, target):
         super(SendNotify, self).__init__(executor)
         self.zone = zone
         self.target = target
 
     def __call__(self):
-        if not CONF['service:worker'].notify:
-            # TODO(timsim): Remove this someday
-            return True
-
         host = self.target.options.get('host')
         port = int(self.target.options.get('port'))
 
         try:
             dnsutils.notify(self.zone.name, host, port=port)
-            LOG.debug('Sent NOTIFY to %(host)s:%(port)s for zone %(zone)s',
-                      {
-                          'host': host,
-                          'port': port,
-                          'zone': self.zone.name
-                      })
+            LOG.debug(
+                'Sent NOTIFY to host=%(host)s:%(port)s for '
+                'zone_name=%(zone_name)s zone_id=%(zone_id)s',
+                {
+                    'host': host,
+                    'port': port,
+                    'zone_name': self.zone.name,
+                    'zone_id': self.zone.id,
+                }
+            )
+
             return True
         except dns.exception.Timeout as e:
-            LOG.info('Timeout on NOTIFY to %(host)s:%(port)s for zone '
-                     '%(zone)s', {
-                         'host': host,
-                         'port': port,
-                         'zone': self.zone.name
-                     })
+            LOG.info(
+                'Timeout on NOTIFY to host=%(host)s:%(port)s for '
+                'zone_name=%(zone_name)s zone_id=%(zone_id)s',
+                {
+                    'host': host,
+                    'port': port,
+                    'zone_name': self.zone.name,
+                    'zone_id': self.zone.id,
+                }
+            )
             raise e
 
         return False
 
 
-class ZoneActor(base.Task, ThresholdMixin):
+class ZoneXfr(base.Task):
+    """
+    Perform AXFR on Zone
+    """
+
+    def __init__(self, executor, context, zone, servers=None):
+        super(ZoneXfr, self).__init__(executor)
+        self.context = context
+        self.zone = zone
+        self.servers = servers
+
+    def __call__(self):
+        servers = self.servers or self.zone.masters
+        if isinstance(servers, objects.ListObjectMixin):
+            servers = servers.to_list()
+
+        try:
+            dnspython_zone = dnsutils.do_axfr(self.zone.name, servers)
+        except exceptions.XFRFailure as e:
+            LOG.warning(e)
+            return
+
+        self.zone.update(dnsutils.from_dnspython_zone(dnspython_zone))
+        self.zone.transferred_at = timeutils.utcnow()
+        self.zone.obj_reset_changes(['name'])
+        self.central_api.update_zone(
+            self.context, self.zone, increment_serial=False
+        )
+
+
+class ZoneActor(base.Task):
     """
     Orchestrate the Create/Update/Delete action on targets and update status
     if it fails. We would only update status here on an error to perform the
@@ -158,15 +196,18 @@ class ZoneActor(base.Task, ThresholdMixin):
     :return: Whether the ActionOnTarget got to a satisfactory number
              of targets (bool)
     """
-    def __init__(self, executor, context, pool, zone):
+
+    def __init__(self, executor, context, pool, zone, zone_params=None):
         super(ZoneActor, self).__init__(executor)
         self.context = context
         self.pool = pool
         self.zone = zone
+        self.zone_params = zone_params
 
     def _execute(self):
         results = self.executor.run([
-            ZoneActionOnTarget(self.executor, self.context, self.zone, target)
+            ZoneActionOnTarget(self.executor, self.context, self.zone, target,
+                               self.zone_params)
             for target in self.pool.targets
         ])
         return results
@@ -177,16 +218,23 @@ class ZoneActor(base.Task, ThresholdMixin):
 
     def _threshold_met(self, results):
         # If we don't meet threshold for action, update status
-        met_action_threshold = self._compare_threshold(
-            results.count(True), len(results))
+        success = results.count(True)
+        total = len(results)
+        met_action_threshold = self.compare_threshold(success, total)
 
         if not met_action_threshold:
-            LOG.info('Could not %(action)s %(zone)s on enough targets. '
-                     'Updating status to ERROR',
-                     {
-                         'action': self.zone.action,
-                         'zone': self.zone.name
-                     })
+            LOG.info(
+                'Could not %(action)s zone_name=%(zone_name)s '
+                'zone_id=%(zone_id)s success=%(success)s '
+                'total=%(total)s on enough targets. Updating status to ERROR',
+                {
+                    'action': self.zone.action,
+                    'zone_name': self.zone.name,
+                    'zone_id': self.zone.id,
+                    'success': success,
+                    'total': total,
+                }
+            )
             self.zone.status = 'ERROR'
             self._update_status()
             return False
@@ -205,13 +253,16 @@ class ZoneAction(base.Task):
     :return: Success/Failure of the change propagating to a satisfactory
              number of nameservers (bool)
     """
-    def __init__(self, executor, context, pool, zone, action):
+
+    def __init__(self, executor, context, pool, zone, action,
+                 zone_params=None):
         super(ZoneAction, self).__init__(executor)
         self.context = context
         self.pool = pool
         self.zone = zone
         self.action = action
         self.task_name = 'ZoneAction-%s' % self.action.title()
+        self.zone_params = zone_params
 
     def _wait_for_nameservers(self):
         """
@@ -221,7 +272,7 @@ class ZoneAction(base.Task):
 
     def _zone_action_on_targets(self):
         actor = ZoneActor(
-            self.executor, self.context, self.pool, self.zone
+            self.executor, self.context, self.pool, self.zone, self.zone_params
         )
         return actor()
 
@@ -230,8 +281,15 @@ class ZoneAction(base.Task):
         return poller()
 
     def __call__(self):
-        LOG.info('Attempting %(action)s on zone %(name)s',
-                 {'action': self.action, 'name': self.zone.name})
+        LOG.info(
+            'Attempting to %(action)s zone_name=%(zone_name)s '
+            'zone_id=%(zone_id)s',
+            {
+                'action': self.action,
+                'zone_name': self.zone.name,
+                'zone_id': self.zone.id,
+            }
+        )
 
         if not self._zone_action_on_targets():
             return False
@@ -291,8 +349,17 @@ def parse_query_results(results, zone):
                     no_zones += 1
 
     result = DNSQueryResult(positives, no_zones, low_serial, results)
-    LOG.debug('Results for polling %(zone)s-%(serial)d: %(tup)s',
-              {'zone': zone.name, 'serial': zone.serial, 'tup': result})
+    LOG.debug(
+        'Results for polling zone_name=%(zone_name)s zone_id=%(zone_id)s '
+        'action=%(action)s serial=%(serial)d query=%(query)s',
+        {
+            'zone_name': zone.name,
+            'zone_id': zone.id,
+            'action': zone.action,
+            'serial': zone.serial,
+            'query': result,
+        }
+    )
     return result
 
 
@@ -304,6 +371,7 @@ class PollForZone(base.Task):
     :return: A serial number if the zone exists (int), None if the zone
     does not exist
     """
+
     def __init__(self, executor, zone, ns):
         super(PollForZone, self).__init__(executor)
         self.zone = zone
@@ -317,45 +385,67 @@ class PollForZone(base.Task):
         )
 
     def __call__(self):
-        LOG.debug('Polling for zone %(zone)s serial %(serial)s on %(ns)s',
-                  {
-                      'zone': self.zone.name,
-                      'serial': self.zone.serial,
-                      'ns': self.ns
-                  })
+        LOG.debug(
+            'Polling serial=%(serial)d for zone_name=%(zone_name)s '
+            'zone_id=%(zone_id)s action=%(action)s on ns=%(ns)s',
+            {
+                'serial': self.zone.serial,
+                'zone_name': self.zone.name,
+                'zone_id': self.zone.id,
+                'action': self.zone.action,
+                'ns': self.ns,
+            }
+        )
 
         try:
             serial = self._get_serial()
-            LOG.debug('Found serial %(serial)d on %(host)s for zone %(zone)s',
-                      {
-                          'serial': serial,
-                          'host': self.ns.host,
-                          'zone': self.zone.name
-                      })
+
+            LOG.debug(
+                'Found serial=%(serial)d for zone_name=%(zone_name)s '
+                'zone_id=%(zone_id)s action=%(action)s on ns=%(ns)s',
+                {
+                    'serial': serial,
+                    'zone_name': self.zone.name,
+                    'zone_id': self.zone.id,
+                    'action': self.zone.action,
+                    'ns': self.ns,
+                }
+            )
             return serial
             # TODO(timsim): cache if it's higher than cache
         except dns.exception.Timeout:
-            LOG.info('Timeout polling for serial %(serial)d '
-                     '%(host)s for zone %(zone)s',
-                     {
-                         'serial': self.zone.serial,
-                         'host': self.ns.host,
-                         'zone': self.zone.name
-                     })
+            LOG.info(
+                'Timeout polling serial=%(serial)d for '
+                'zone_name=%(zone_name)s zone_id=%(zone_id)s '
+                'action=%(action)s on ns=%(ns)s',
+                {
+                    'serial': self.zone.serial,
+                    'zone_name': self.zone.name,
+                    'zone_id': self.zone.id,
+                    'action': self.zone.action,
+                    'ns': self.ns,
+                }
+            )
+
         except Exception as e:
-            LOG.warning('Unexpected failure polling for serial %(serial)d '
-                        '%(host)s for zone %(zone)s. Error: %(error)s',
-                        {
-                            'serial': self.zone.serial,
-                            'host': self.ns.host,
-                            'zone': self.zone.name,
-                            'error': str(e)
-                        })
+            LOG.warning(
+                'Unexpected failure polling serial=%(serial)d for '
+                'zone_name=%(zone_name)s zone_id=%(zone_id)s '
+                'action=%(action)s on ns=%(ns)s Error=%(error)s',
+                {
+                    'serial': self.zone.serial,
+                    'zone_name': self.zone.name,
+                    'zone_id': self.zone.id,
+                    'action': self.zone.action,
+                    'ns': self.ns,
+                    'error': str(e),
+                }
+            )
 
         return None
 
 
-class ZonePoller(base.Task, ThresholdMixin):
+class ZonePoller(base.Task):
     """
     Orchestrate polling for a change across the nameservers in a pool
     and compute the proper zone status, and update it.
@@ -363,6 +453,7 @@ class ZonePoller(base.Task, ThresholdMixin):
     :return: Whether the change was successfully polled for on a satisfactory
              number of nameservers in the pool
     """
+
     def __init__(self, executor, context, pool, zone):
         super(ZonePoller, self).__init__(executor)
         self.context = context
@@ -385,7 +476,6 @@ class ZonePoller(base.Task, ThresholdMixin):
 
         retry_interval = self.retry_interval
         query_result = DNSQueryResult(0, 0, 0, 0)
-        results = []
         for retry in range(0, self.max_retries):
             results = self.executor.run([
                 PollForZone(self.executor, self.zone, ns)
@@ -394,13 +484,28 @@ class ZonePoller(base.Task, ThresholdMixin):
 
             query_result = parse_query_results(results, self.zone)
 
-            if self._compare_threshold(query_result.positives, len(results)):
-                LOG.debug('Successful poll for %(zone)s',
-                         {'zone': self.zone.name})
+            if self.compare_threshold(query_result.positives, len(results)):
+                LOG.debug(
+                    'Successful poll for zone_name=%(zone_name)s '
+                    'zone_id=%(zone_id)s action=%(action)s',
+                    {
+                        'zone_name': self.zone.name,
+                        'zone_id': self.zone.id,
+                        'action': self.zone.action,
+                    }
+                )
                 break
+            LOG.debug(
+                'Unsuccessful poll for zone_name=%(zone_name)s '
+                'zone_id=%(zone_id)s action=%(action)s on attempt=%(attempt)d',
+                {
+                    'zone_name': self.zone.name,
+                    'zone_id': self.zone.id,
+                    'action': self.zone.action,
+                    'attempt': retry + 1,
+                }
+            )
 
-            LOG.debug('Unsuccessful poll for %(zone)s on attempt %(n)d',
-                      {'zone': self.zone.name, 'n': retry + 1})
             time.sleep(retry_interval)
 
             if not self.is_current_action_valid(self.context, self.zone.action,
@@ -410,12 +515,16 @@ class ZonePoller(base.Task, ThresholdMixin):
         return query_result
 
     def _on_failure(self, error_status):
-        LOG.info('Could not find %(serial)s for %(zone)s on enough '
-                 'nameservers.',
-                 {
-                     'serial': self.zone.serial,
-                     'zone': self.zone.name
-                 })
+        LOG.info(
+            'Could not find serial=%(serial)d for zone_name=%(zone_name)s '
+            'zone_id=%(zone_id)s action=%(action)s on enough nameservers',
+            {
+                'serial': self.zone.serial,
+                'zone_name': self.zone.name,
+                'zone_id': self.zone.id,
+                'action': self.zone.action,
+            }
+        )
 
         self.zone.status = error_status
 
@@ -427,8 +536,16 @@ class ZonePoller(base.Task, ThresholdMixin):
     def _on_success(self, query_result, status):
         # TODO(timsim): Change this back to active, so dumb central
         self.zone.status = status
-        LOG.debug('Found success for %(zone)s at serial %(serial)d',
-                  {'zone': self.zone.name, 'serial': self.zone.serial})
+        LOG.debug(
+            'Found success for zone_name=%(zone_name)s '
+            'zone_id=%(zone_id)s action=%(action)s at serial=%(serial)d',
+            {
+                'zone_name': self.zone.name,
+                'zone_id': self.zone.id,
+                'action': self.zone.action,
+                'serial': self.zone.serial,
+            }
+        )
 
         self.zone.serial = query_result.consensus_serial
         return True
@@ -452,7 +569,7 @@ class ZonePoller(base.Task, ThresholdMixin):
 
         # Ensure if we don't have too many nameservers that
         # don't have the zone.
-        over_no_zone_threshold = self._compare_threshold(
+        over_no_zone_threshold = self.compare_threshold(
             (total - query_result.no_zones), total
         )
 
@@ -461,7 +578,7 @@ class ZonePoller(base.Task, ThresholdMixin):
 
         # The action should have been pushed out to a minimum
         # number of nameservers.
-        if not self._compare_threshold(query_result.positives, total):
+        if not self.compare_threshold(query_result.positives, total):
             return False, 'ERROR'
 
         # We have success of the action on the nameservers and enough
@@ -481,6 +598,136 @@ class ZonePoller(base.Task, ThresholdMixin):
         return result
 
 
+class GetZoneSerial(base.Task):
+    """
+    Get zone serial number from a resolver using retries.
+    """
+    def __init__(self, executor, context, zone, host, port):
+        super(GetZoneSerial, self).__init__(executor)
+        self.context = context
+        self.zone = zone
+        self.host = host
+        self.port = port
+        self.serial_max_retries = CONF['service:worker'].serial_max_retries
+        self.serial_retry_delay = CONF['service:worker'].serial_retry_delay
+        self.serial_timeout = CONF['service:worker'].serial_timeout
+
+    def __call__(self):
+        LOG.debug(
+            'Sending SOA for zone_name=%(zone)s to %(server)s:%(port)d.',
+            {
+                'zone': self.zone.name,
+                'server': self.host,
+                'port': self.port,
+            }
+        )
+        actual_serial = None
+        status = 'ERROR'
+        for retry in range(0, self.serial_max_retries):
+            response = self._make_and_send_soa_message(
+                self.zone.name, self.host, self.port
+            )
+            if not response:
+                pass
+            elif (response.rcode() in (
+                    dns.rcode.NXDOMAIN,
+                    dns.rcode.REFUSED,
+                    dns.rcode.SERVFAIL) or not bool(response.answer)):
+                status = 'NO_ZONE'
+                if (self.zone.serial == 0 and
+                        self.zone.action in ('DELETE', 'NONE')):
+                    actual_serial = 0
+                    break
+            elif not (response.flags & dns.flags.AA):
+                LOG.warning(
+                    'Unable to get serial for zone_name=%(zone)s '
+                    'to %(server)s:%(port)d. '
+                    'Unable to get an Authoritative Answer from server.',
+                    {
+                        'zone': self.zone.name,
+                        'server': self.host,
+                        'port': self.port,
+                    }
+                )
+                break
+            elif dns.rcode.from_flags(
+                    response.flags, response.ednsflags) != dns.rcode.NOERROR:
+                pass
+            elif (len(response.answer) == 1 and
+                  str(response.answer[0].name) == self.zone.name and
+                  response.answer[0].rdclass == dns.rdataclass.IN and
+                  response.answer[0].rdtype == dns.rdatatype.SOA):
+                rrset = response.answer[0]
+                actual_serial = list(rrset.to_rdataset().items)[0].serial
+
+            if actual_serial is not None:
+                status = 'SUCCESS'
+                break
+            time.sleep(self.serial_retry_delay)
+
+        if actual_serial is None:
+            LOG.warning(
+                'Unable to get serial for zone_name=%(zone)s'
+                'to %(server)s:%(port)d.',
+                {
+                    'zone': self.zone.name,
+                    'server': self.host,
+                    'port': self.port,
+                }
+            )
+
+        return status, actual_serial
+
+    def _make_and_send_soa_message(self, zone_name, host, port):
+        """
+        Generate and send a SOA message.
+
+        :param zone_name: The zone name.
+        :param host: The destination host for the dns message.
+        :param port: The destination port for the dns message.
+        """
+        try:
+            return dnsutils.soa_query(
+                zone_name, host, port, timeout=self.serial_timeout
+            )
+        except socket.error as e:
+            if e.errno != errno.EAGAIN:
+                raise
+            LOG.info(
+                'Got EAGAIN while trying to send SOA for '
+                'zone_name=%(zone_name)s to %(server)s:%(port)d. '
+                'timeout=%(timeout)d seconds.',
+                {
+                    'zone_name': zone_name,
+                    'server': host,
+                    'port': port,
+                    'timeout': self.serial_timeout
+                }
+            )
+        except dns.exception.Timeout:
+            LOG.warning(
+                'Got Timeout while trying to send SOA for '
+                'zone_name=%(zone_name)s to %(server)s:%(port)d. '
+                'timeout=%(timeout)d seconds.',
+                {
+                    'zone_name': zone_name,
+                    'server': host,
+                    'port': port,
+                    'timeout': self.serial_timeout
+                }
+            )
+        except dns.query.BadResponse:
+            LOG.warning(
+                'Got BadResponse while trying to send SOA '
+                'for zone_name=%(zone_name)s to %(server)s:%(port)d.',
+                {
+                    'zone_name': zone_name,
+                    'server': host,
+                    'port': port,
+                }
+            )
+
+
 ###################
 # Status Management
 ###################
@@ -493,6 +740,7 @@ class UpdateStatus(base.Task):
 
     :return: No return value
     """
+
     def __init__(self, executor, context, zone):
         super(UpdateStatus, self).__init__(executor)
         self.zone = zone
@@ -500,10 +748,13 @@ class UpdateStatus(base.Task):
 
     def __call__(self):
         LOG.debug(
-            'Updating status for %(zone)s to %(status)s:%(action)s', {
-                'zone': self.zone.name,
-                'status': self.zone.status,
+            'Updating status for zone_name=%(zone_name)s '
+            'zone_id=%(zone_id)s to action=%(action)s serial=%(serial)d',
+            {
+                'zone_name': self.zone.name,
+                'zone_id': self.zone.id,
                 'action': self.zone.action,
+                'serial': self.zone.serial,
             }
         )
 
@@ -527,6 +778,7 @@ class RecoverShard(base.Task):
 
     :return: No return value
     """
+
     def __init__(self, executor, context, begin, end):
         super(RecoverShard, self).__init__(executor)
         self.context = context
@@ -563,8 +815,18 @@ class RecoverShard(base.Task):
 
     def __call__(self):
         zones = self._get_zones()
-
         for zone in zones:
+            LOG.debug(
+                'Trying to recover zone_name=%(zone_name)s '
+                'zone_id=%(zone_id)s action=%(action)s status=%(status)s',
+                {
+                    'zone_name': zone.name,
+                    'zone_id': zone.id,
+                    'action': zone.action,
+                    'status': zone.status,
+                }
+            )
+
             if zone.action == 'CREATE':
                 self.worker_api.create_zone(self.context, zone)
             elif zone.action == 'UPDATE':
@@ -583,6 +845,7 @@ class ExportZone(base.Task):
     perform the necessary actions to Export the zone, and update the
     export row in storage via central.
     """
+
     def __init__(self, executor, context, zone, export):
         super(ExportZone, self).__init__(executor)
         self.context = context
@@ -612,16 +875,17 @@ class ExportZone(base.Task):
         if synchronous:
             try:
                 self.quota.limit_check(
-                        context, context.project_id, api_export_size=size)
+                    context, context.project_id, api_export_size=size)
             except exceptions.OverQuota:
                 LOG.debug('Zone Export too large to perform synchronously')
                 export.status = 'ERROR'
                 export.message = 'Zone is too large to export'
                 return export
 
-            export.location = \
-                'designate://v2/zones/tasks/exports/%(eid)s/export' % \
-                {'eid': export.id}
+            export.location = (
+                    'designate://v2/zones/tasks/exports/%(eid)s/export' %
+                    {'eid': export.id}
+            )
 
             export.status = 'COMPLETE'
         else:
